from flask import jsonify, Blueprint
from app import db
from sqlalchemy import inspect

db_routes = Blueprint('db_routes', __name__)



@db_routes.route('/tables')
def get_tables():
    inspector = inspect(db.engine)
    tables = inspector.get_table_names()
    return jsonify({'tables': tables})

@db_routes.route('/tables/<table_name>')
def get_table_data(table_name):
    inspector = inspect(db.engine)
    if table_name not in inspector.get_table_names():
        return jsonify({'error': 'Table not found'}), 404
    
    columns = inspector.get_columns(table_name)
    return jsonify({'columns': columns})


@db_routes.route('/tables/<table_name>/<column_name>')
def get_column_data(table_name, column_name):
    inspector = inspect(db.engine)
    if table_name not in inspector.get_table_names():
        return jsonify({'error': 'Table not found'}), 404
    
    if column_name not in inspector.get_columns(table_name):
        return jsonify({'error': 'Column not found'}), 404
    
    data = db.session.query(table_name).all()
    return jsonify({'data': data})

@db_routes.route('/tables/<table_name>/<column_name>/<value>')
def get_value_data(table_name, column_name, value):
    inspector = inspect(db.engine)
    if table_name not in inspector.get_table_names():
        return jsonify({'error': 'Table not found'}), 404
    
    if column_name not in inspector.get_columns(table_name):
        return jsonify({'error': 'Column not found'}), 404
    
    data = db.session.query(table_name).filter(column_name == value).all()
    return jsonify({'data': data})