import sqlalchemy
from sqlalchemy import Table, Column, Integer, String, MetaData, select, insert, inspect, update, delete
from datetime import datetime
from flask import Flask, jsonify, request, current_app
class SQL:
    def __init__(self, engine):
        self.engine = engine

    def get_tables(self):
        inspector = inspect(self.engine)
        return inspector.get_table_names()

    def get_columns(self, table_name):
        inspector = inspect(self.engine)
        return inspector.get_columns(table_name)

    def get_data(self, table_name):
        with self.engine.connect() as connection:
            result = connection.execute(select([table_name]))
            return result.fetchall()

    def insert_data(self, table_name, data):
        with self.engine.connect() as connection:
            connection.execute(insert(table_name), data)

    def update_data(self, table_name, column_name, value, new_value):
        with self.engine.connect() as connection:
            connection.execute(update(table_name).where(column_name == value), new_value)

    def delete_data(self, table_name, column_name, value):
        with self.engine.connect() as connection:
            connection.execute(delete(table_name).where(column_name == value))

class SQL_USER:
    def __init__(self, db):
        self.db = db
        self._table = None
    @property
    def table(self):
        if self._table is None:
            with current_app.app_context():
                metadata = MetaData()
                self._table = Table('users', metadata, autoload_with=self.db.engine)
        return self._table
    
    def get_user(self, userid):
        with current_app.app_context():
            result = self.db.session.execute(select(self.table).where(self.table.c.user_id == userid))
            return [list(row) for row in result.fetchall()]

    def get_all_users(self):
        with current_app.app_context():
            result = self.db.session.execute(select(self.table))
            return [list(row) for row in result.fetchall()]

    def add_user(self, email, first_name=None, last_name=None, password=None, birthday=None, creation_date=None, last_access_date=None, updated_at=None, enabled=None, role=None, athletic_ability=None):
        if email is None:
            return {'error': 'Email is required'}
        data = {
            'email': email,
            'first_name': first_name,
            'last_name': last_name,
            'password': password,
            'birthday': birthday,
            'creation_date': creation_date or datetime.now(),
            'last_access_date': last_access_date or datetime.now(),
            'updated_at': updated_at or datetime.now(),
            'enabled': enabled,
            'role': "user",
            'athletic_ability': athletic_ability
        }
        with current_app.app_context():
            self.db.session.execute(insert(self.table).values(**data))
            self.db.session.commit()
        return {'success': 'User added successfully'}




    def check_login(self, email, password):
        with current_app.app_context():
            result = self.db.session.execute(
                select(self.table).where(
                    (self.table.c.email == email) & (self.table.c.password == password)
                )
            ).first()
            return result is not None


