import React, { useState, useEffect } from "react";
import LoginPage from './login-page';  // The presentational component

const LoginPageLogic = () => {
  const [username, setUsername] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');

  const handleSubmit = async (e) => {
    e.preventDefault();
    setError('');

    try {
      // await fetch sends a secret request via api/login
      // this is what routes.py is listening for
      const response = await fetch('http://localhost:5000/check_login', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ username, password }),
      });

      const data = await response.json();
      if (response.ok) {
        alert('Login successful!');
        window.location.href = '/home';
      } else {
        setError(data.message || 'Invalid login');
      }
    } catch (err) {
      setError('Error connecting to the server');
    }
  };

  return (
    <LoginPage
      username={username}
      setUsername={setUsername}
      password={password}
      setPassword={setPassword}
      handleSubmit={handleSubmit}
      error={error}
    />
  );
};

export default LoginPageLogic;
